@@ -1005,11 +1005,20 @@ void OPENGL_GAL::DrawArc( const VECTOR2D& aCenterPoint, double aRadius,
 
         VECTOR2D p( cos( startAngle ) * aRadius, sin( startAngle ) * aRadius );
         double   alpha;
+        unsigned int lineCount = 0;
+
+        for( alpha = startAngle + alphaIncrement; alpha <= endAngle; alpha += alphaIncrement )
+            lineCount++;
+
+        if( alpha != endAngle )
+            lineCount++;
+
+        reserveLineQuads( lineCount );
 
         for( alpha = startAngle + alphaIncrement; alpha <= endAngle; alpha += alphaIncrement )
         {
             VECTOR2D p_next( cos( alpha ) * aRadius, sin( alpha ) * aRadius );
-            DrawLine( p, p_next );
+            drawLineQuad( p, p_next, false );
 
             p = p_next;
         }
@@ -1018,7 +1027,7 @@ void OPENGL_GAL::DrawArc( const VECTOR2D& aCenterPoint, double aRadius,
         if( alpha != endAngle )
         {
             VECTOR2D p_last( cos( endAngle ) * aRadius, sin( endAngle ) * aRadius );
-            DrawLine( p, p_last );
+            drawLineQuad( p, p_last, false );
         }
     }
 
@@ -1058,9 +1067,21 @@ void OPENGL_GAL::DrawArcSegment( const VECTOR2D& aCenterPoint, double aRadius,
     if( seg_count % 2 != 0 )
         seg_count += 1;
 
+    // Our shaders have trouble rendering null line quads, so delegate this task to DrawSegment.
+    if( seg_count == 0 )
+    {
+        VECTOR2D p_start( aCenterPoint.x + cos( startAngle ) * aRadius,
+                          aCenterPoint.y + sin( startAngle ) * aRadius );
+
+        VECTOR2D p_end( aCenterPoint.x + cos( endAngle ) * aRadius,
+                        aCenterPoint.y + sin( endAngle ) * aRadius );
+
+        DrawSegment( p_start, p_end, aWidth );
+        return;
+    }
+
     // Recalculate alphaIncrement with a even integer number of segment
-    if( seg_count )
-        alphaIncrement = ( endAngle - startAngle ) / seg_count;
+    alphaIncrement = ( endAngle - startAngle ) / seg_count;
 
     Save();
     m_currentManager->Translate( aCenterPoint.x, aCenterPoint.y, 0.0 );
@@ -2891,30 +2912,9 @@ void OPENGL_GAL::DrawGlyphs( const std::vector<std::unique_ptr<KIFONT::GLYPH>>&
     }
     else if( allGlyphsAreOutline )
     {
-        // Optimized path for stroke fonts that pre-reserves glyph triangles.
+        // Optimized path for outline fonts that pre-reserves glyph triangles.
         int triangleCount = 0;
 
-        if( aGlyphs.size() > 0 )
-        {
-            thread_pool& tp = GetKiCadThreadPool();
-
-            tp.push_loop( aGlyphs.size(),
-                    [&]( const int a, const int b)
-                    {
-                        for( int ii = a; ii < b; ++ii )
-                        {
-                            auto glyph = static_cast<KIFONT::OUTLINE_GLYPH*>( aGlyphs.at( ii ).get() );
-
-                            // Only call CacheTriangulation() if it has never been done before.
-                            // Otherwise we'll hash the triangulation to see if it has been edited,
-                            // and all our glpyh editing ops update the triangulation anyway.
-                            if( glyph->TriangulatedPolyCount() == 0 )
-                                glyph->CacheTriangulation( false );
-                        }
-                    } );
-            tp.wait_for_tasks();
-        }
-
         for( const std::unique_ptr<KIFONT::GLYPH>& glyph : aGlyphs )
         {
             const auto& outlineGlyph = static_cast<const KIFONT::OUTLINE_GLYPH&>( *glyph );
