@@ -199,6 +199,11 @@ public:
 
     void RemoveItem( SCH_ITEM* aItem );
 
+    /**
+     * Replaces all references to #aOldItem with #aNewItem in the subgraph.
+    */
+    void ExchangeItem( SCH_ITEM* aOldItem, SCH_ITEM* aNewItem );
+
     // Use this to keep a connection pointer that is not owned by any item
     // This will be destroyed with the subgraph
     void StoreImplicitConnection( SCH_CONNECTION* aConnection )
@@ -301,6 +306,8 @@ private:
     /// A cache of connections that are part of this subgraph but that don't have
     /// an owning element (i.e. bus members)
     std::set<SCH_CONNECTION*> m_bus_element_connections;
+
+    std::mutex m_driver_mutex;
 };
 
 struct NET_NAME_CODE_CACHE_KEY
@@ -454,6 +461,11 @@ public:
 
     void RemoveItem( SCH_ITEM* aItem );
 
+    /**
+     * Replace all references to #aOldItem with #aNewItem in the graph.
+    */
+    void ExchangeItem( SCH_ITEM* aOldItem, SCH_ITEM* aNewItem );
+
 private:
     /**
      * Update the graphical connectivity between items (i.e. where they touch)
@@ -497,8 +509,12 @@ private:
      * the driver is first selected by CONNECTION_SUBGRAPH::ResolveDrivers(),
      * and then the connection for the chosen driver is propagated to all the
      * other items in the subgraph.
+     *
+     * If the unconitional flag is set, all existing net classes will be removed
+     * and re-created.  Otherwise, we will preserve existing net classes that do not
+     * conflict with the new net classes.
      */
-    void buildConnectionGraph( std::function<void( SCH_ITEM* )>* aChangedItemHandler );
+    void buildConnectionGraph( std::function<void( SCH_ITEM* )>* aChangedItemHandler, bool aUnconditional );
 
     /**
      * Generate individual item subgraphs on a per-sheet basis.
