@@ -23,6 +23,7 @@
 #include <algorithm>
 
 #include <bitmaps.h>
+#include <connection_graph.h>
 #include <string_utils.h>   // WildCompareString
 #include <kiway.h>
 #include <refdes_utils.h>
@@ -47,6 +48,7 @@ bool g_resetFieldVisibilities[2] = { true,   false  };
 bool g_resetFieldEffects[2]      = { true,   false  };
 bool g_resetFieldPositions[2]    = { true,   false  };
 bool g_resetAttributes[2]        = { true,   false  };
+bool g_resetCustomPower[2]       = { false,  false  };
 
 
 DIALOG_CHANGE_SYMBOLS::DIALOG_CHANGE_SYMBOLS( SCH_EDIT_FRAME* aParent, SCH_SYMBOL* aSymbol,
@@ -146,6 +148,7 @@ DIALOG_CHANGE_SYMBOLS::DIALOG_CHANGE_SYMBOLS( SCH_EDIT_FRAME* aParent, SCH_SYMBO
     m_resetFieldEffects->SetValue( g_resetFieldEffects[ (int) m_mode ] );
     m_resetFieldPositions->SetValue( g_resetFieldPositions[ (int) m_mode ] );
     m_resetAttributes->SetValue( g_resetAttributes[ (int) m_mode ] );
+    m_resetCustomPower->SetValue( g_resetCustomPower[ (int) m_mode ] );
 
     // DIALOG_SHIM needs a unique hash_key because classname is not sufficient
     // because the update and change versions of this dialog have different controls.
@@ -227,6 +230,7 @@ DIALOG_CHANGE_SYMBOLS::~DIALOG_CHANGE_SYMBOLS()
     g_resetFieldEffects[ (int) m_mode ] = m_resetFieldEffects->GetValue();
     g_resetFieldPositions[ (int) m_mode ] = m_resetFieldPositions->GetValue();
     g_resetAttributes[ (int) m_mode ] = m_resetAttributes->GetValue();
+    g_resetCustomPower[ (int) m_mode ] = m_resetCustomPower->GetValue();
 }
 
 
@@ -540,7 +544,8 @@ int DIALOG_CHANGE_SYMBOLS::processMatchingSymbols( SCH_COMMIT* aCommit )
 
 
 int DIALOG_CHANGE_SYMBOLS::processSymbols( SCH_COMMIT* aCommit,
-                                           const std::map<SCH_SYMBOL*, SYMBOL_CHANGE_INFO>& aSymbols )
+                                           const std::map<SCH_SYMBOL*,
+                                           SYMBOL_CHANGE_INFO>& aSymbols )
 {
     wxCHECK( !aSymbols.empty(), 0 );
 
@@ -598,11 +603,24 @@ int DIALOG_CHANGE_SYMBOLS::processSymbols( SCH_COMMIT* aCommit,
         wxCHECK( screen, 0 );
 
         screen->Remove( symbol );
-        aCommit->Modify( symbol, screen );
+        SCH_SYMBOL* symbol_copy = static_cast<SCH_SYMBOL*>( symbol->Clone() );
+        aCommit->Modified( symbol, symbol_copy, screen );
+
+        CONNECTION_GRAPH*           connectionGraph = screen->Schematic()->ConnectionGraph();
+
+        // When we replace the lib symbol below, we free the associated pins if the new symbol has
+        // fewer than the original.  This will cause the connection graph to be out of date unless
+        // we replace references in the graph to the old symbol/pins with references to the ones stored
+        // in the undo stack.
+        if( connectionGraph )
+            connectionGraph->ExchangeItem( symbol, symbol_copy );
     }
 
     for( const auto& [ symbol, symbol_change_info ] : symbols )
     {
+        // Remember initial link before changing for diags purpose
+        wxString initialLibLinkName = UnescapeString( symbol->GetLibId().Format() );
+
         if( symbol_change_info.m_LibId != symbol->GetLibId() )
             symbol->SetLibId( symbol_change_info.m_LibId );
 
@@ -650,15 +668,26 @@ int DIALOG_CHANGE_SYMBOLS::processSymbols( SCH_COMMIT* aCommit,
                 {
                     if( i == REFERENCE_FIELD )
                     {
+                        wxString prefix = UTIL::GetRefDesPrefix( libField->GetText() );
+
                         for( const SCH_SHEET_PATH& instance : symbol_change_info.m_Instances )
                         {
-                            symbol->SetRef( &instance,
-                                            UTIL::GetRefDesUnannotated( libField->GetText() ) );
+                            wxString ref = symbol->GetRef( &instance );
+                            int      number = UTIL::GetRefDesNumber( ref );
+
+                            if( number >= 0 )
+                                ref.Printf( wxS( "%s%d" ), prefix, number );
+                            else
+                                ref = UTIL::GetRefDesUnannotated( prefix );
+
+                            symbol->SetRef( &instance, ref );
                         }
                     }
                     else if( i == VALUE_FIELD )
                     {
-                        symbol->SetValueFieldText( UnescapeString( libField->GetText() ) );
+                        if( ( symbol->IsPower() && m_resetCustomPower->IsChecked() )
+                            || !symbol->IsPower() )
+                            symbol->SetValueFieldText( UnescapeString( libField->GetText() ) );
                     }
                     else if( i == FOOTPRINT_FIELD )
                     {
@@ -732,7 +761,7 @@ int DIALOG_CHANGE_SYMBOLS::processSymbols( SCH_COMMIT* aCommit,
 
         frame->GetCanvas()->GetView()->Update( symbol );
 
-        msg = getSymbolReferences( *symbol, symbol_change_info.m_LibId );
+        msg = getSymbolReferences( *symbol, symbol_change_info.m_LibId, &initialLibLinkName );
         msg += wxS( ": OK" );
         m_messagePanel->Report( msg, RPT_SEVERITY_ACTION );
         matchesProcessed +=1;
@@ -742,12 +771,21 @@ int DIALOG_CHANGE_SYMBOLS::processSymbols( SCH_COMMIT* aCommit,
 }
 
 
-wxString DIALOG_CHANGE_SYMBOLS::getSymbolReferences( SCH_SYMBOL& aSymbol, const LIB_ID& aNewId )
+wxString DIALOG_CHANGE_SYMBOLS::getSymbolReferences( SCH_SYMBOL& aSymbol,
+                                                     const LIB_ID& aNewId,
+                                                     const wxString* aOldLibLinkName )
 {
     wxString msg;
     wxString references;
     LIB_ID oldId = aSymbol.GetLibId();
 
+    wxString oldLibLinkName;    // For report
+
+    if( aOldLibLinkName )
+        oldLibLinkName = *aOldLibLinkName;
+    else
+        oldLibLinkName = UnescapeString( oldId.Format() );
+
     SCH_EDIT_FRAME* parent = dynamic_cast< SCH_EDIT_FRAME* >( GetParent() );
 
     wxCHECK( parent, msg );
@@ -772,31 +810,31 @@ wxString DIALOG_CHANGE_SYMBOLS::getSymbolReferences( SCH_SYMBOL& aSymbol, const
         {
             msg.Printf( _( "Update symbol %s from '%s' to '%s'" ),
                         references,
-                        UnescapeString( oldId.Format() ),
+                        oldLibLinkName,
                         UnescapeString( aNewId.Format() ) );
         }
         else
         {
             msg.Printf( _( "Update symbols %s from '%s' to '%s'" ),
                         references,
-                        UnescapeString( oldId.Format() ),
+                        oldLibLinkName,
                         UnescapeString( aNewId.Format() ) );
         }
     }
-    else
+    else    // mode is MODE::CHANGE
     {
         if( aSymbol.GetInstances().size() == 1 )
         {
             msg.Printf( _( "Change symbol %s from '%s' to '%s'" ),
                         references,
-                        UnescapeString( oldId.Format() ),
+                        oldLibLinkName,
                         UnescapeString( aNewId.Format() ) );
         }
         else
         {
             msg.Printf( _( "Change symbols %s from '%s' to '%s'" ),
                         references,
-                        UnescapeString( oldId.Format() ),
+                        oldLibLinkName,
                         UnescapeString( aNewId.Format() ) );
         }
     }
