@@ -34,6 +34,7 @@
 #include <wildcards_and_files_ext.h>
 #include <widgets/std_bitmap_button.h>
 #include <kiplatform/ui.h>
+#include <sch_commit.h>
 #include <sch_edit_frame.h>
 #include <sch_sheet.h>
 #include <schematic.h>
@@ -45,10 +46,12 @@
 #include "wx/dcclient.h"
 
 DIALOG_SHEET_PROPERTIES::DIALOG_SHEET_PROPERTIES( SCH_EDIT_FRAME* aParent, SCH_SHEET* aSheet,
-                                                  bool* aClearAnnotationNewItems ) :
+                                                  bool* aClearAnnotationNewItems,
+                                                  bool* aUpdateHierarchyNavigator ) :
     DIALOG_SHEET_PROPERTIES_BASE( aParent ),
     m_frame( aParent ),
     m_clearAnnotationNewItems( aClearAnnotationNewItems ),
+    m_updateHierarchyNavigator( aUpdateHierarchyNavigator ),
     m_borderWidth( aParent, m_borderWidthLabel, m_borderWidthCtrl, m_borderWidthUnits ),
     m_dummySheet( *aSheet ),
     m_dummySheetNameField( VECTOR2I( -1, -1 ), SHEETNAME, &m_dummySheet )
@@ -257,9 +260,17 @@ static bool positioningChanged( FIELDS_GRID_TABLE<SCH_FIELD>* a, std::vector<SCH
 
 bool DIALOG_SHEET_PROPERTIES::TransferDataFromWindow()
 {
+    wxCHECK( m_sheet && m_frame, false );
+
     if( !wxDialog::TransferDataFromWindow() )  // Calls our Validate() method.
         return false;
 
+    SCH_COMMIT commit( m_frame );
+
+    commit.Modify( m_sheet, m_frame->GetScreen() );
+
+    bool isUndoable = true;
+
     // Sheet file names can be relative or absolute.
     wxString sheetFileName = m_fields->at( SHEETFILENAME ).GetText();
 
@@ -328,13 +339,17 @@ bool DIALOG_SHEET_PROPERTIES::TransferDataFromWindow()
             }
         }
 
-        if( !onSheetFilenameChanged( newRelativeFilename ) )
+        if( !onSheetFilenameChanged( newRelativeFilename, &isUndoable ) )
         {
             if( clearFileName )
                 currentScreen->SetFileName( wxEmptyString );
 
             return false;
         }
+        else if( m_updateHierarchyNavigator )
+        {
+            *m_updateHierarchyNavigator = true;
+        }
 
         if( clearFileName )
             currentScreen->SetFileName( wxEmptyString );
@@ -345,6 +360,9 @@ bool DIALOG_SHEET_PROPERTIES::TransferDataFromWindow()
 
     wxString newSheetname = m_fields->at( SHEETNAME ).GetText();
 
+    if( ( newSheetname != m_sheet->GetName() ) && m_updateHierarchyNavigator )
+        *m_updateHierarchyNavigator = true;
+
     if( newSheetname.IsEmpty() )
         newSheetname = _( "Untitled Sheet" );
 
@@ -407,14 +425,26 @@ bool DIALOG_SHEET_PROPERTIES::TransferDataFromWindow()
     for( SCH_ITEM* item : m_frame->GetScreen()->Items().OfType( SCH_SHEET_T ) )
         m_frame->UpdateItem( item );
 
-    m_frame->OnModify();
+    if( isUndoable )
+    {
+        commit.Push( _( "Edit Sheet Properties" ) );
+    }
+    else
+    {
+        // If we are renaming files, the undo/redo list becomes invalid and must be cleared.
+        m_frame->ClearUndoRedoList();
+        m_frame->OnModify();
+    }
 
     return true;
 }
 
 
-bool DIALOG_SHEET_PROPERTIES::onSheetFilenameChanged( const wxString& aNewFilename )
+bool DIALOG_SHEET_PROPERTIES::onSheetFilenameChanged( const wxString& aNewFilename,
+                                                      bool* aIsUndoable )
 {
+    wxCHECK( aIsUndoable, false );
+
     wxString   msg;
     wxFileName sheetFileName(
             EnsureFileExtension( aNewFilename, FILEEXT::KiCadSchematicFileExtension ) );
@@ -494,7 +524,6 @@ bool DIALOG_SHEET_PROPERTIES::onSheetFilenameChanged( const wxString& aNewFilena
     }
     else                                    // Existing sheet.
     {
-        bool isUndoable = true;
         isExistingSheet = true;
 
         if( !m_frame->AllowCaseSensitiveFileNameClashes( newAbsoluteFilename ) )
@@ -515,7 +544,7 @@ bool DIALOG_SHEET_PROPERTIES::onSheetFilenameChanged( const wxString& aNewFilena
         if( newAbsoluteFilename.Cmp( oldAbsoluteFilename ) != 0 )
         {
             // Sheet file name changes cannot be undone.
-            isUndoable = false;
+            *aIsUndoable = false;
 
             if( useScreen || loadFromFile )           // Load from existing file.
             {
@@ -553,12 +582,6 @@ bool DIALOG_SHEET_PROPERTIES::onSheetFilenameChanged( const wxString& aNewFilena
             }
         }
 
-        // If we are renaming files, the undo/redo list becomes invalid and must be cleared
-        if( isUndoable )
-            m_frame->SaveCopyInUndoList( m_frame->GetScreen(), m_sheet, UNDO_REDO::CHANGED, false );
-        else
-            m_frame->ClearUndoRedoList();
-
         if( renameFile )
         {
             IO_RELEASER<SCH_IO> pi( SCH_IO_MGR::FindPlugin( SCH_IO_MGR::SCH_KICAD ) );
@@ -614,6 +637,12 @@ bool DIALOG_SHEET_PROPERTIES::onSheetFilenameChanged( const wxString& aNewFilena
 
         // It's safe to set the sheet screen now.
         m_sheet->SetScreen( useScreen );
+
+        SCH_SHEET_LIST sheetHierarchy( m_sheet );  // The hierarchy of the loaded file.
+
+        sheetHierarchy.AddNewSymbolInstances( currentSheet );
+        sheetHierarchy.AddNewSheetInstances( currentSheet,
+                                             fullHierarchy.GetLastVirtualPageNumber() );
     }
     else if( loadFromFile )
     {
