@@ -146,13 +146,17 @@ protected:
                 {
                     if( m_fieldsCtrl->GetTextValue( row, FIELD_NAME_COLUMN ) == fieldName )
                     {
-                        m_fieldsCtrl->SetToggleValue( show, row, SHOW_FIELD_COLUMN );
+                        if( m_grid->CommitPendingChanges( false ) )
+                            m_fieldsCtrl->SetToggleValue( show, row, SHOW_FIELD_COLUMN );
+
                         break;
                     }
                 }
             }
             else
+            {
                 GRID_TRICKS::doPopupSelection( event );
+            }
         }
     }
 
@@ -1039,6 +1043,10 @@ void DIALOG_SYMBOL_FIELDS_TABLE::OnTableCellClick( wxGridEvent& event )
 
 void DIALOG_SYMBOL_FIELDS_TABLE::OnTableRangeSelected( wxGridRangeSelectEvent& aEvent )
 {
+    // Cross-probing should only work in Edit page
+    if( m_nbPages->GetSelection() != 0 )
+        return;
+
     // Multi-select can grab the rows that are expanded child refs, and also the row
     // containing the list of all child refs. Make sure we add refs/symbols uniquely
     std::set<SCH_REFERENCE> refs;
@@ -1063,10 +1071,10 @@ void DIALOG_SYMBOL_FIELDS_TABLE::OnTableRangeSelected( wxGridRangeSelectEvent& a
 
         if( refs.size() > 0 )
         {
-            // Use of full path based on UUID allows select of not yet annotated or duplicaded symbols
+            // Use of full path based on UUID allows select of not yet annotated or duplicated symbols
             wxString symbol_path = refs.begin()->GetFullPath();
 
-            // Focus only handles on item at this time
+            // Focus only handles one item at this time
             editor->FindSymbolAndItem( &symbol_path, nullptr, true, HIGHLIGHT_SYMBOL,
                                        wxEmptyString );
         }
@@ -1288,6 +1296,7 @@ void DIALOG_SYMBOL_FIELDS_TABLE::OnExport( wxCommandEvent& aEvent )
         return;
     }
 
+    out.Close(); // close the file before we tell the user it's done with the info modal :workflow meme:
     msg.Printf( _( "Wrote BOM output to '%s'" ), outputFile.GetFullPath() );
     DisplayInfoMessage( this, msg );
 }
