@@ -1718,7 +1718,7 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_COMMIT* aCommit, SCH_CLEANUP_FL
     {
         PICKED_ITEMS_LIST* changed_list = m_undoList.m_CommandsList.back();
         std::set<SCH_ITEM*> changed_items;
-        std::vector<VECTOR2I> pts;
+        std::set<VECTOR2I> pts;
         std::set<std::pair<SCH_SHEET_PATH, SCH_ITEM*>> item_paths;
 
         for( unsigned ii = 0; ii < changed_list->GetCount(); ++ii )
@@ -1733,23 +1733,47 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_COMMIT* aCommit, SCH_CLEANUP_FL
             SCH_SHEET_PATHS& paths = screen->GetClientSheetPaths();
 
             std::vector<VECTOR2I> tmp_pts = item->GetConnectionPoints();
-            pts.insert( pts.end(), tmp_pts.begin(), tmp_pts.end() );
+            pts.insert( tmp_pts.begin(), tmp_pts.end() );
             changed_items.insert( item );
 
+            for( SCH_SHEET_PATH& path : paths )
+                item_paths.insert( std::make_pair( path, item ) );
+
+            item = dynamic_cast<SCH_ITEM*>( changed_list->GetPickedItemLink( ii ) );
+
+            if( !item || !item->IsConnectable() )
+                continue;
+
+            tmp_pts = item->GetConnectionPoints();
+            pts.insert( tmp_pts.begin(), tmp_pts.end() );
+            changed_items.insert( item );
+
+            // We have to directly add the pins here because the link may not exist on the schematic
+            // anymore and so won't be picked up by GetScreen()->Items().Overlapping() below.
+            if( SCH_SYMBOL* symbol = dynamic_cast<SCH_SYMBOL*>( item ) )
+            {
+                std::vector<SCH_PIN*> pins = symbol->GetPins();
+                changed_items.insert( pins.begin(), pins.end() );
+            }
+
             for( SCH_SHEET_PATH& path : paths )
                 item_paths.insert( std::make_pair( path, item ) );
         }
 
-        for( VECTOR2I& pt: pts )
+        for( const VECTOR2I& pt: pts )
         {
             for( SCH_ITEM* item : GetScreen()->Items().Overlapping( pt ) )
             {
+                // Leave this check in place.  Overlapping items are not necessarily connectable.
+                if( !item->IsConnectable() )
+                    continue;
+
                 if( item->Type() == SCH_LINE_T )
                 {
                     if( item->HitTest( pt ) )
                         changed_items.insert( item );
                 }
-                else if( item->Type() == SCH_SYMBOL_T )
+                else if( item->Type() == SCH_SYMBOL_T && item->IsConnected( pt ) )
                 {
                     SCH_SYMBOL*           symbol = static_cast<SCH_SYMBOL*>( item );
                     std::vector<SCH_PIN*> pins = symbol->GetPins();
@@ -1767,7 +1791,6 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_COMMIT* aCommit, SCH_CLEANUP_FL
                 }
                 else
                 {
-                    // Non-connectable objects have already been pruned.
                     if( item->IsConnected( pt ) )
                         changed_items.insert( item );
                 }
@@ -1786,21 +1809,7 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_COMMIT* aCommit, SCH_CLEANUP_FL
         for( auto&[ path, item ] : all_items )
         {
             wxCHECK2( item, continue );
-
-            switch( item->Type() )
-            {
-            case SCH_FIELD_T:
-            case SCH_PIN_T:
-            {
-                SCH_ITEM* parent = static_cast<SCH_ITEM*>( item->GetParent() );
-                wxCHECK2( parent, continue );
-                parent->SetConnectivityDirty();
-                break;
-            }
-
-            default:
-                item->SetConnectivityDirty();
-            }
+            item->SetConnectivityDirty();
         }
 
         new_graph.Recalculate( list, false, &changeHandler );
