@@ -175,48 +175,6 @@ static ELECTRICAL_PINTYPE ConvertElecType( const wxString& aType )
 }
 
 
-static void TransformToBaseline( EDA_TEXT* textItem, const wxString& baselineAlign, bool invertY )
-{
-    int upOffset = 0;
-
-    if( baselineAlign == wxS( "" ) || baselineAlign == wxS( "auto" )
-        || baselineAlign == wxS( "use-script" ) || baselineAlign == wxS( "no-change" )
-        || baselineAlign == wxS( "reset-size" ) || baselineAlign == wxS( "alphabetic" )
-        || baselineAlign == wxS( "inherit" ) )
-    {
-        upOffset = textItem->GetTextSize().y;
-    }
-    else if( baselineAlign == wxS( "ideographic" ) || baselineAlign == wxS( "text-after-edge" ) )
-    {
-        upOffset = textItem->GetTextSize().y * 1.2;
-    }
-    else if( baselineAlign == wxS( "central" ) )
-    {
-        upOffset = textItem->GetTextSize().y * 0.5;
-    }
-    else if( baselineAlign == wxS( "middle" ) )
-    {
-        upOffset = textItem->GetTextSize().y * 0.6;
-    }
-    else if( baselineAlign == wxS( "mathematical" ) )
-    {
-        upOffset = textItem->GetTextSize().y * 0.1;
-    }
-    else if( baselineAlign == wxS( "hanging" ) || baselineAlign == wxS( "text-before-edge" ) )
-    {
-        upOffset = 0;
-    }
-
-    VECTOR2I offset( 0, -upOffset );
-    RotatePoint( offset, textItem->GetTextAngle() );
-
-    if( invertY )
-        offset.y = -offset.y;
-
-    textItem->SetTextPos( textItem->GetTextPos() + offset );
-}
-
-
 VECTOR2I HelperGeneratePowerPortGraphics( LIB_SYMBOL* aKsymbol, EASYEDA::POWER_FLAG_STYLE aStyle,
                                           REPORTER* aReporter )
 {
@@ -487,11 +445,11 @@ void SCH_EASYEDA_PARSER::ParseSymbolShapes( LIB_SYMBOL*                  aSymbol
             wxString   fillColor = arr[5].Lower();
             //bool       locked = arr[7] != wxS( "0" );
 
-             std::vector<SHAPE_LINE_CHAIN> lineChains =
+            std::vector<SHAPE_LINE_CHAIN> lineChains =
                     ParseLineChains( pointsData, schIUScale.MilsToIU( 10 ), false );
 
             for( SHAPE_LINE_CHAIN outline : lineChains )
-             {
+            {
                 std::unique_ptr<LIB_SHAPE> shape =
                         std::make_unique<LIB_SHAPE>( aSymbol, SHAPE_T::POLY );
 
@@ -848,6 +806,55 @@ void SCH_EASYEDA_PARSER::ParseSymbolShapes( LIB_SYMBOL*                  aSymbol
             int pinUnit = 0;
             int kPinLen = ScaleSize( std::abs( pinLen ) );
 
+            if( segments.size() > 5 )
+            {
+                wxArrayString dotParts = wxSplit( segments[5], '~', '\0' );
+                wxArrayString clockParts = wxSplit( segments[6], '~', '\0' );
+
+                if( dotParts.size() == 3 && clockParts.size() == 2 )
+                {
+                    if( dotParts[0] == wxS( "1" ) )
+                    {
+                        VECTOR2D dotPos( Convert( dotParts[1] ), Convert( dotParts[2] ) );
+
+                        std::unique_ptr<LIB_SHAPE> circle =
+                                std::make_unique<LIB_SHAPE>( aSymbol, SHAPE_T::CIRCLE );
+
+                        circle->SetCenter( RelPosSym( dotPos ) );
+                        circle->SetEnd( RelPosSym(
+                                pinPos + ( dotPos - pinPos ).Resize( std::abs( pinLen ) ) ) );
+
+                        circle->SetUnit( 0 );
+
+                        aSymbol->AddDrawItem( circle.release() );
+                    }
+
+                    if( clockParts[0] == wxS( "1" ) )
+                    {
+                        std::vector<SHAPE_LINE_CHAIN> lineChains =
+                                ParseLineChains( clockParts[1], schIUScale.MilsToIU( 10 ), false );
+
+                        for( SHAPE_LINE_CHAIN outline : lineChains )
+                        {
+                            std::unique_ptr<LIB_SHAPE> shape =
+                                    std::make_unique<LIB_SHAPE>( aSymbol, SHAPE_T::POLY );
+
+                            outline.Mirror( false, true );
+
+                            if( outline.IsClosed() )
+                                outline.Append( outline.CPoint( 0 ), true );
+
+                            for( const VECTOR2I& pt : outline.CPoints() )
+                                shape->AddPoint( pt );
+
+                            shape->SetUnit( 0 );
+
+                            aSymbol->AddDrawItem( shape.release() );
+                        }
+                    }
+                }
+            }
+
             std::unique_ptr<LIB_PIN> pin = std::make_unique<LIB_PIN>( aSymbol );
 
             pin->SetName( pinName );
@@ -879,6 +886,7 @@ void SCH_EASYEDA_PARSER::ParseSymbolShapes( LIB_SYMBOL*                  aSymbol
             wxString fontSize = arr[7];
             wxString baselineAlign = arr[10];
             wxString textStr = arr[12];
+            bool     visible = arr[13] != wxS( "0" );
 
             textStr.Replace( wxS( "\\n" ), wxS( "\n" ) );
             textStr = UnescapeHTML( textStr );
@@ -916,6 +924,7 @@ void SCH_EASYEDA_PARSER::ParseSymbolShapes( LIB_SYMBOL*                  aSymbol
                 textItem->SetHorizJustify( GR_TEXT_H_ALIGN_LEFT );
 
             textItem->SetFont( KIFONT::FONT::GetFont( fontname ) );
+            textItem->SetVisible( visible );
 
             double ptSize = 7;
 
@@ -936,7 +945,7 @@ void SCH_EASYEDA_PARSER::ParseSymbolShapes( LIB_SYMBOL*                  aSymbol
 
             textItem->SetTextSize( VECTOR2I( ktextSize, ktextSize ) );
 
-            TransformToBaseline( textItem, baselineAlign, true );
+            TransformTextToBaseline( textItem, baselineAlign, true );
 
             if( added )
                 aSymbol->AddDrawItem( dynamic_cast<LIB_ITEM*>( textItem ) );
@@ -1299,7 +1308,7 @@ void SCH_EASYEDA_PARSER::ParseSchematic( SCHEMATIC* aSchematic, SCH_SHEET* aRoot
 
                 valField->SetTextSize( VECTOR2I( ktextSize, ktextSize ) );
 
-                //TransformToBaseline( valField, wxS( "" ), true );
+                //TransformTextToBaseline( valField, wxS( "" ), true );
 
                 createdItems.push_back( std::move( schSym ) );
             }
@@ -1418,7 +1427,7 @@ void SCH_EASYEDA_PARSER::ParseSchematic( SCHEMATIC* aSchematic, SCH_SHEET* aRoot
 
             textItem->SetTextSize( VECTOR2I( ktextSize, ktextSize ) );
 
-            TransformToBaseline( textItem.get(), baselineAlign, false );
+            TransformTextToBaseline( textItem.get(), baselineAlign, false );
 
             createdItems.push_back( std::move( textItem ) );
         }
