@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2016 Jean-Pierre Charras, jp.charras at wanadoo.fr
  * Copyright (C) 2015 Wayne Stambaugh <stambaughw@gmail.com>
- * Copyright (C) 1992-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -274,7 +274,7 @@ bool SCH_LABEL_BASE::IsType( const std::vector<KICAD_T>& aScanTypes ) const
     if( m_connected_items.find( Schematic()->CurrentSheet() ) == m_connected_items.end() )
         return false;
 
-    const SCH_ITEM_SET& item_set = m_connected_items.at( Schematic()->CurrentSheet() );
+    const SCH_ITEM_VEC& item_set = m_connected_items.at( Schematic()->CurrentSheet() );
 
     for( KICAD_T scanType : aScanTypes )
     {
@@ -407,6 +407,7 @@ VECTOR2I SCH_LABEL_BASE::GetSchematicTextOffset( const RENDER_SETTINGS* aSetting
     return text_offset;
 }
 
+
 void SCH_LABEL_BASE::SetPosition( const VECTOR2I& aPosition )
 {
     VECTOR2I offset = aPosition - GetTextPos();
@@ -1101,16 +1102,19 @@ bool SCH_LABEL_BASE::HitTest( const BOX2I& aRect, bool aContained, int aAccuracy
 }
 
 
-bool SCH_LABEL_BASE::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemList,
-                                          const SCH_SHEET_PATH* aPath )
+bool SCH_LABEL_BASE::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemListByType,
+                                          std::vector<DANGLING_END_ITEM>& aItemListByPos,
+                                          const SCH_SHEET_PATH*           aPath )
 {
-    bool previousState = m_isDangling;
-    m_isDangling       = true;
+    bool     previousState = m_isDangling;
+    VECTOR2I text_pos = GetTextPos();
+    m_isDangling = true;
     m_connectionType   = CONNECTION_TYPE::NONE;
 
-    for( unsigned ii = 0; ii < aItemList.size(); ii++ )
+    for( auto it = DANGLING_END_ITEM_HELPER::get_lower_pos( aItemListByPos, text_pos );
+         it < aItemListByPos.end() && it->GetPosition() == text_pos; it++ )
     {
-        DANGLING_END_ITEM& item = aItemList[ii];
+        DANGLING_END_ITEM& item = *it;
 
         if( item.GetItem() == this )
             continue;
@@ -1121,33 +1125,68 @@ bool SCH_LABEL_BASE::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemL
         case LABEL_END:
         case SHEET_LABEL_END:
         case NO_CONNECT_END:
-            if( GetTextPos() == item.GetPosition() )
+            if( text_pos == item.GetPosition() )
             {
                 m_isDangling = false;
 
                 if( aPath && item.GetType() != PIN_END )
                     AddConnectionTo( *aPath, static_cast<SCH_ITEM*>( item.GetItem() ) );
             }
-
             break;
 
-        case BUS_END:
-            m_connectionType = CONNECTION_TYPE::BUS;
-            KI_FALLTHROUGH;
+        default: break;
+        }
 
-        case WIRE_END:
+        if( !m_isDangling )
+            break;
+    }
+
+    if( m_isDangling )
+    {
+        for( auto it = DANGLING_END_ITEM_HELPER::get_lower_type( aItemListByType, BUS_END );
+             it < aItemListByType.end() && it->GetType() == BUS_END; it++ )
         {
-            DANGLING_END_ITEM& nextItem = aItemList[++ii];
+            DANGLING_END_ITEM& item = *it;
+            DANGLING_END_ITEM& nextItem = *( ++it );
 
-            int accuracy = 1;   // We have rounding issues with an accuracy of 0
+            int accuracy = 1; // We have rounding issues with an accuracy of 0
 
-            m_isDangling = !TestSegmentHit( GetTextPos(), item.GetPosition(),
-                                            nextItem.GetPosition(), accuracy );
+            m_isDangling = !TestSegmentHit( text_pos, item.GetPosition(), nextItem.GetPosition(),
+                                            accuracy );
 
-            if( !m_isDangling )
+            if( m_isDangling )
+                continue;
+
+            m_connectionType = CONNECTION_TYPE::BUS;
+
+            // Add the line to the connected items, since it won't be picked
+            // up by a search of intersecting connection points
+            if( aPath )
             {
-                if( m_connectionType != CONNECTION_TYPE::BUS )
-                    m_connectionType = CONNECTION_TYPE::NET;
+                auto sch_item = static_cast<SCH_ITEM*>( item.GetItem() );
+                AddConnectionTo( *aPath, sch_item );
+                sch_item->AddConnectionTo( *aPath, this );
+            }
+            break;
+        }
+
+        if( m_isDangling )
+        {
+            for( auto it = DANGLING_END_ITEM_HELPER::get_lower_type( aItemListByType, WIRE_END );
+                 it < aItemListByType.end() && it->GetType() == WIRE_END; it++ )
+            {
+                DANGLING_END_ITEM& item = *it;
+                DANGLING_END_ITEM& nextItem = *( ++it );
+
+                int accuracy = 1; // We have rounding issues with an accuracy of 0
+
+                m_isDangling = !TestSegmentHit( text_pos, item.GetPosition(),
+                                                nextItem.GetPosition(), accuracy );
+
+                if( m_isDangling )
+                    continue;
+
+                m_connectionType = CONNECTION_TYPE::NET;
 
                 // Add the line to the connected items, since it won't be picked
                 // up by a search of intersecting connection points
@@ -1157,16 +1196,9 @@ bool SCH_LABEL_BASE::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemL
                     AddConnectionTo( *aPath, sch_item );
                     sch_item->AddConnectionTo( *aPath, this );
                 }
+                break;
             }
         }
-            break;
-
-        default:
-            break;
-        }
-
-        if( !m_isDangling )
-            break;
     }
 
     if( m_isDangling )
@@ -1176,6 +1208,25 @@ bool SCH_LABEL_BASE::UpdateDanglingState( std::vector<DANGLING_END_ITEM>& aItemL
 }
 
 
+bool SCH_LABEL_BASE::HasConnectivityChanges( const SCH_ITEM* aItem,
+                                             const SCH_SHEET_PATH* aInstance ) const
+{
+    // Do not compare to ourself.
+    if( aItem == this || !IsConnectable() )
+        return false;
+
+    const SCH_LABEL_BASE* label = dynamic_cast<const SCH_LABEL_BASE*>( aItem );
+
+    // Don't compare against a different SCH_ITEM.
+    wxCHECK( label, false );
+
+    if( GetPosition() != label->GetPosition() )
+        return true;
+
+    return GetShownText( aInstance ) != label->GetShownText( aInstance );
+}
+
+
 void SCH_LABEL_BASE::GetMsgPanelInfo( EDA_DRAW_FRAME* aFrame, std::vector<MSG_PANEL_ITEM>& aList )
 {
     wxString msg;
@@ -1305,7 +1356,8 @@ void SCH_LABEL_BASE::Plot( PLOTTER* aPlotter, bool aBackground,
                 properties.emplace_back( wxString::Format( wxT( "!%s = %s" ), _( "Net" ),
                                                            connection->Name() ) );
 
-                properties.emplace_back( wxString::Format( wxT( "!%s = %s" ), _( "Resolved netclass" ),
+                properties.emplace_back( wxString::Format( wxT( "!%s = %s" ),
+                                                           _( "Resolved netclass" ),
                                                            GetEffectiveNetClass()->GetName() ) );
             }
 
@@ -1374,16 +1426,19 @@ void SCH_LABEL_BASE::Print( const RENDER_SETTINGS* aSettings, const VECTOR2I& aO
         field.Print( aSettings, aOffset );
 }
 
+
 bool SCH_LABEL_BASE::AutoRotateOnPlacement() const
 {
     return m_autoRotateOnPlacement;
 }
 
+
 void SCH_LABEL_BASE::SetAutoRotateOnPlacement( bool autoRotate )
 {
     m_autoRotateOnPlacement = autoRotate;
 }
 
+
 SCH_LABEL::SCH_LABEL( const VECTOR2I& pos, const wxString& text ) :
         SCH_LABEL_BASE( pos, text, SCH_LABEL_T )
 {
@@ -1584,6 +1639,7 @@ void SCH_DIRECTIVE_LABEL::CreateGraphicShape( const RENDER_SETTINGS* aRenderSett
         aPoints.emplace_back( VECTOR2I(             0, 0                        ) );
         aPoints.emplace_back( VECTOR2I(             0, m_pinLength - symbolSize ) );
         aPoints.emplace_back( VECTOR2I(             0, m_pinLength              ) );
+
         // These points are just used to bulk out the bounding box
         aPoints.emplace_back( VECTOR2I( -m_symbolSize, m_pinLength              ) );
         aPoints.emplace_back( VECTOR2I(             0, m_pinLength              ) );
@@ -2156,8 +2212,10 @@ static struct SCH_DIRECTIVE_LABEL_DESC
         propMgr.Mask( TYPE_HASH( SCH_DIRECTIVE_LABEL ), TYPE_HASH( EDA_TEXT ), _HKI( "Thickness" ) );
         propMgr.Mask( TYPE_HASH( SCH_DIRECTIVE_LABEL ), TYPE_HASH( EDA_TEXT ), _HKI( "Italic" ) );
         propMgr.Mask( TYPE_HASH( SCH_DIRECTIVE_LABEL ), TYPE_HASH( EDA_TEXT ), _HKI( "Bold" ) );
-        propMgr.Mask( TYPE_HASH( SCH_DIRECTIVE_LABEL ), TYPE_HASH( EDA_TEXT ), _HKI( "Horizontal Justification" ) );
-        propMgr.Mask( TYPE_HASH( SCH_DIRECTIVE_LABEL ), TYPE_HASH( EDA_TEXT ), _HKI( "Vertical Justification" ) );
+        propMgr.Mask( TYPE_HASH( SCH_DIRECTIVE_LABEL ), TYPE_HASH( EDA_TEXT ),
+                      _HKI( "Horizontal Justification" ) );
+        propMgr.Mask( TYPE_HASH( SCH_DIRECTIVE_LABEL ), TYPE_HASH( EDA_TEXT ),
+                      _HKI( "Vertical Justification" ) );
     }
 } _SCH_DIRECTIVE_LABEL_DESC;
 
