@@ -26,13 +26,21 @@
 #include <tool/picker_tool.h>
 #include <tools/sch_edit_tool.h>
 #include <tools/ee_selection_tool.h>
+#include <tools/ee_inspection_tool.h>
 #include <tools/sch_line_wire_bus_tool.h>
 #include <tools/sch_move_tool.h>
 #include <tools/sch_drawing_tools.h>
 #include <ee_actions.h>
 #include <confirm.h>
 #include <string_utils.h>
+#include <sch_bitmap.h>
+#include <sch_bus_entry.h>
+#include <sch_commit.h>
+#include <sch_edit_frame.h>
 #include <sch_item.h>
+#include <sch_junction.h>
+#include <sch_line.h>
+#include <sch_marker.h>
 #include <sch_symbol.h>
 #include <sch_shape.h>
 #include <sch_sheet.h>
@@ -41,12 +49,7 @@
 #include <sch_textbox.h>
 #include <sch_bitmap.h>
 #include <sch_view.h>
-#include <sch_line.h>
-#include <sch_bus_entry.h>
-#include <sch_junction.h>
-#include <sch_edit_frame.h>
 #include <schematic.h>
-#include <sch_commit.h>
 #include <drawing_sheet/ds_proxy_view_item.h>
 #include <eeschema_id.h>
 #include <dialogs/dialog_change_symbols.h>
@@ -138,12 +141,13 @@ private:
         EE_SELECTION_TOOL* selTool = getToolManager()->GetTool<EE_SELECTION_TOOL>();
         EE_SELECTION&      selection = selTool->GetSelection();
         SCH_PIN*           pin = dynamic_cast<SCH_PIN*>( selection.Front() );
+        LIB_PIN*           libPin = pin ? pin->GetLibPin() : nullptr;
 
         Clear();
 
-        wxCHECK( pin, /* void */ );
+        wxCHECK( libPin, /* void */ );
 
-        wxMenuItem* item = Append( ID_POPUP_SCH_ALT_PIN_FUNCTION, pin->GetName(), wxEmptyString,
+        wxMenuItem* item = Append( ID_POPUP_SCH_ALT_PIN_FUNCTION, libPin->GetName(), wxEmptyString,
                                    wxITEM_CHECK );
 
         if( pin->GetAlt().IsEmpty() )
@@ -151,7 +155,7 @@ private:
 
         int ii = 1;
 
-        for( const auto& [ name, definition ] : pin->GetLibPin()->GetAlternates() )
+        for( const auto& [ name, definition ] : libPin->GetAlternates() )
         {
             item = Append( ID_POPUP_SCH_ALT_PIN_FUNCTION + ii, name, wxEmptyString, wxITEM_CHECK );
 
@@ -1546,7 +1550,7 @@ void SCH_EDIT_TOOL::editFieldText( SCH_FIELD* aField )
         static_cast<SCH_ITEM*>( aField->GetParent() )->AutoAutoplaceFields( m_frame->GetScreen() );
 
     if( !commit.Empty() )
-        commit.Push( caption, SKIP_CONNECTIVITY );
+        commit.Push( caption );
 }
 
 
@@ -1718,7 +1722,7 @@ int SCH_EDIT_TOOL::ChangeBodyStyle( const TOOL_EVENT& aEvent )
 
 int SCH_EDIT_TOOL::Properties( const TOOL_EVENT& aEvent )
 {
-    EE_SELECTION& selection = m_selectionTool->RequestSelection( EE_COLLECTOR::EditableItems );
+    EE_SELECTION& selection = m_selectionTool->RequestSelection();
     bool          clearSelection = selection.IsHover();
 
     if( selection.Empty() )
@@ -1830,6 +1834,7 @@ int SCH_EDIT_TOOL::Properties( const TOOL_EVENT& aEvent )
         SCH_SHEET*     sheet = static_cast<SCH_SHEET*>( curr_item );
         bool           doClearAnnotation;
         bool           doRefresh = false;
+        bool           updateHierarchyNavigator = false;
 
         // Keep track of existing sheet paths. EditSheet() can modify this list.
         // Note that we use the validity checking/repairing version here just to make sure
@@ -1837,7 +1842,7 @@ int SCH_EDIT_TOOL::Properties( const TOOL_EVENT& aEvent )
         SCH_SHEET_LIST originalHierarchy( &m_frame->Schematic().Root(), true );
 
         doRefresh = m_frame->EditSheetProperties( sheet, &m_frame->GetCurrentSheet(),
-                                                  &doClearAnnotation );
+                                                  &doClearAnnotation, &updateHierarchyNavigator );
 
         // If the sheet file is changed and new sheet contents are loaded then we have to
         // clear the annotations on the new content (as it may have been set from some other
@@ -1856,10 +1861,10 @@ int SCH_EDIT_TOOL::Properties( const TOOL_EVENT& aEvent )
         }
 
         if( doRefresh )
-        {
             m_frame->GetCanvas()->Refresh();
+
+        if( updateHierarchyNavigator )
             m_frame->UpdateHierarchyNavigator();
-        }
 
         break;
     }
@@ -2002,8 +2007,19 @@ int SCH_EDIT_TOOL::Properties( const TOOL_EVENT& aEvent )
 
         break;
 
-    case SCH_MARKER_T:        // These items have no properties to edit
+    case SCH_MARKER_T:
+        if( SELECTION_CONDITIONS::OnlyTypes( { SCH_MARKER_T } )( selection ) )
+        {
+            EE_INSPECTION_TOOL* inspectionTool = m_toolMgr->GetTool<EE_INSPECTION_TOOL>();
+
+            if( inspectionTool )
+                inspectionTool->CrossProbe( static_cast<SCH_MARKER*> ( selection.Front() ) );
+        }
+        break;
+
     case SCH_NO_CONNECT_T:
+    case SCH_PIN_T:
+
         break;
 
     default:                // Unexpected item
