@@ -80,6 +80,14 @@
 #include <wx/treectrl.h>
 
 
+/**
+ * Flag to enable schematic paste debugging output.
+ *
+ * @ingroup trace_env_vars
+ */
+static const wxChar traceSchPaste[] = wxT( "KICAD_SCH_PASTE" );
+
+
 int SCH_EDITOR_CONTROL::New( const TOOL_EVENT& aEvent )
 {
     m_frame->NewProject();
@@ -1248,16 +1256,6 @@ int SCH_EDITOR_CONTROL::Undo( const TOOL_EVENT& aEvent )
 
     m_frame->PutDataInPreviousState( undo_list );
 
-    // Only rebuild the hierarchy navigator if there are sheet changes.
-    if( undo_list->ContainsItemType( SCH_SHEET_T ) )
-    {
-        m_frame->SetSheetNumberAndCount();
-        m_frame->UpdateHierarchyNavigator();
-    }
-
-    m_frame->RecalculateConnections( nullptr, NO_CLEANUP );
-    m_frame->TestDanglingEnds();
-
     // Now push the old command to the RedoList
     undo_list->ReversePickersListOrder();
     m_frame->PushCommandToRedoList( undo_list );
@@ -1293,16 +1291,6 @@ int SCH_EDITOR_CONTROL::Redo( const TOOL_EVENT& aEvent )
     list->ReversePickersListOrder();
     m_frame->PushCommandToUndoList( list );
 
-    // Only rebuild the hierarchy navigator if there are sheet changes.
-    if( list->ContainsItemType( SCH_SHEET_T ) )
-    {
-        m_frame->SetSheetNumberAndCount();
-        m_frame->UpdateHierarchyNavigator();
-    }
-
-    m_frame->RecalculateConnections( nullptr, NO_CLEANUP );
-    m_frame->TestDanglingEnds();
-
     m_toolMgr->GetTool<EE_SELECTION_TOOL>()->RebuildSelection();
 
     m_frame->GetCanvas()->Refresh();
@@ -1437,12 +1425,16 @@ void SCH_EDITOR_CONTROL::updatePastedSymbol( SCH_SYMBOL* aSymbol,
 
     for( const SCH_SYMBOL_INSTANCE& tmp : aSymbol->GetInstances() )
     {
-        if( tmp.m_Path.EndsWith( aClipPath ) )
+        if( ( tmp.m_Path.empty() && aClipPath.empty() )
+          || ( !aClipPath.empty() && tmp.m_Path.EndsWith( aClipPath ) ) )
         {
             newInstance = tmp;
             instanceFound = true;
 
-            wxLogDebug( wxS( "Pasting found symbol instance:\n\tpath: %s\n\tuuid: %s." ),
+            wxLogTrace( traceSchPaste,
+                        wxS( "Pasting found symbol instance with reference %s, unit %d:"
+                             "\n\tClipboard path: %s\n\tSymbol UUID: %s." ),
+                        tmp.m_Reference, tmp.m_Unit,
                         aClipPath.AsString(), aSymbol->m_Uuid.AsString() );
 
             break;
@@ -1454,7 +1446,9 @@ void SCH_EDITOR_CONTROL::updatePastedSymbol( SCH_SYMBOL* aSymbol,
 
     if( !instanceFound )
     {
-        wxLogDebug( wxS( "Clipboard symbol instance **not** found:\n\tpath: %s\n\tuuid: %s." ),
+        wxLogTrace( traceSchPaste,
+                    wxS( "Clipboard symbol instance **not** found:\n\tClipboard path: %s\n\t"
+                         "Symbol UUID: %s." ),
                     aClipPath.AsString(), aSymbol->m_Uuid.AsString() );
 
         // Some legacy versions saved value fields escaped.  While we still do in the symbol
@@ -1486,7 +1480,8 @@ SCH_SHEET_PATH SCH_EDITOR_CONTROL::updatePastedSheet( SCH_SHEET* aSheet,
                                                       const KIID_PATH& aClipPath,
                                                       bool aForceKeepAnnotations,
                                                       SCH_SHEET_LIST* aPastedSheets,
-                                                      std::map<SCH_SHEET_PATH, SCH_REFERENCE_LIST>& aPastedSymbols )
+                                                      std::map<SCH_SHEET_PATH,
+                                                      SCH_REFERENCE_LIST>& aPastedSymbols )
 {
     wxCHECK( aSheet && aPastedSheets, aPastePath );
 
@@ -2333,8 +2328,18 @@ int SCH_EDITOR_CONTROL::ExportNetlist( const TOOL_EVENT& aEvent )
 
 int SCH_EDITOR_CONTROL::GenerateBOM( const TOOL_EVENT& aEvent )
 {
-    EditSymbolFields( aEvent );
-    m_frame->GetSymbolFieldsTableDialog()->ShowExportTab();
+    DIALOG_SYMBOL_FIELDS_TABLE* dlg = m_frame->GetSymbolFieldsTableDialog();
+
+    wxCHECK( dlg, 0 );
+
+    // Needed at least on Windows. Raise() is not enough
+    dlg->Show( true );
+
+    // Bring it to the top if already open.  Dual monitor users need this.
+    dlg->Raise();
+
+    dlg->ShowExportTab();
+
     return 0;
 }
 
