@@ -198,7 +198,7 @@ GERBVIEW_FRAME::GERBVIEW_FRAME( KIWAY* aKiway, wxWindow* aParent )
 
     // Register a call to update the toolbar sizes. It can't be done immediately because
     // it seems to require some sizes calculated that aren't yet (at least on GTK).
-    CallAfter( [&]()
+    CallAfter( [this]()
                {
                    // Ensure the controls on the toolbars all are correctly sized
                     UpdateToolbarControlSizes();
@@ -552,6 +552,8 @@ void GERBVIEW_FRAME::RemapLayers( const std::unordered_map<int, int>& remapping
 {
     // Save the visibility of each existing gerber layer, in order to be able
     // to restore this visibility after layer reorder.
+    // Note: the visibility of other objects (D_CODE, negative objects ... )
+    // must be not modified
     for( int currlayer = GERBER_DRAWLAYERS_COUNT-1; currlayer >= 0; --currlayer )
     {
         GERBER_FILE_IMAGE* gerber = GetImagesList()->GetGbrImage( currlayer );
@@ -576,8 +578,8 @@ void GERBVIEW_FRAME::RemapLayers( const std::unordered_map<int, int>& remapping
 
     GetCanvas()->GetView()->ReorderLayerData( view_remapping );
 
-    // Restore visibility options
-    LSET newVisibility;
+    // Restore visibility of gerber layers
+    LSET newVisibility = GetVisibleLayers();
 
     for( int currlayer = GERBER_DRAWLAYERS_COUNT-1; currlayer >= 0; --currlayer )
     {
@@ -587,6 +589,8 @@ void GERBVIEW_FRAME::RemapLayers( const std::unordered_map<int, int>& remapping
         {
             if( gerber->HasFlag( CANDIDATE ) )
                 newVisibility.set( currlayer );
+            else
+                newVisibility.set( currlayer, false );
 
             gerber->ClearFlags( CANDIDATE );
         }
@@ -596,6 +600,12 @@ void GERBVIEW_FRAME::RemapLayers( const std::unordered_map<int, int>& remapping
 
     ReFillLayerWidget();
     syncLayerBox( true );
+
+    // Reordering draw layers need updating the view items
+    GetCanvas()->GetView()->RecacheAllItems();
+    GetCanvas()->GetView()->MarkDirty();
+    GetCanvas()->GetView()->UpdateAllItems( KIGFX::ALL );
+
     GetCanvas()->Refresh();
 }
 
