@@ -62,6 +62,7 @@
 #include <string_utils.h>
 #include <core/thread_pool.h>
 #include <zone.h>
+#include <mutex>
 
 // This is an odd place for this, but CvPcb won't link if it's in board_item.cpp like I first
 // tried it.
@@ -79,6 +80,8 @@ BOARD::BOARD() :
         m_project( nullptr ),
         m_userUnits( EDA_UNITS::MILLIMETRES ),
         m_designSettings( new BOARD_DESIGN_SETTINGS( nullptr, "board.design_settings" ) ),
+        m_deleting( false ),
+        m_maxClearanceValue( 0 ),
         m_NetInfo( this )
 {
     // A too small value do not allow connecting 2 shapes (i.e. segments) not exactly connected
@@ -130,6 +133,8 @@ BOARD::BOARD() :
 
 BOARD::~BOARD()
 {
+    m_deleting = true;
+
     // Untangle group parents before doing any deleting
     for( PCB_GROUP* group : m_groups )
     {
@@ -253,6 +258,8 @@ void BOARD::IncrementTimeStamp()
 {
     m_timeStamp++;
 
+    UpdateMaxClearanceCache();
+
     if( !m_IntersectsAreaCache.empty()
         || !m_EnclosedByAreaCache.empty()
         || !m_IntersectsCourtyardCache.empty()
@@ -262,7 +269,7 @@ void BOARD::IncrementTimeStamp()
         || !m_ZoneBBoxCache.empty()
         || m_CopperItemRTreeCache )
     {
-        std::unique_lock<std::mutex> cacheLock( m_CachesMutex );
+        std::unique_lock<std::shared_mutex> writeLock( m_CachesMutex );
 
         m_IntersectsAreaCache.clear();
         m_EnclosedByAreaCache.clear();
@@ -771,8 +778,12 @@ BOARD_DESIGN_SETTINGS& BOARD::GetDesignSettings() const
 }
 
 
-int BOARD::GetMaxClearanceValue() const
+void BOARD::UpdateMaxClearanceCache()
 {
+    // in destructor, useless work
+    if( m_deleting )
+        return;
+
     int worstClearance = m_designSettings->GetBiggestClearanceValue();
 
        for( ZONE* zone : m_zones )
@@ -789,7 +800,7 @@ int BOARD::GetMaxClearanceValue() const
             worstClearance = std::max( worstClearance, zone->GetLocalClearance() );
     }
 
-    return worstClearance;
+    m_maxClearanceValue = worstClearance;
 }
 
 
