@@ -40,6 +40,7 @@
 #include <tools/pcb_actions.h>
 #include <wildcards_and_files_ext.h>
 #include <pcb_marker.h>
+#include <pgm_base.h>
 #include <wx/filedlg.h>
 #include <wx/wupdlock.h>
 #include <widgets/appearance_controls.h>
@@ -72,7 +73,8 @@ DIALOG_DRC::DIALOG_DRC( PCB_EDIT_FRAME* aEditorFrame, wxWindow* aParent ) :
         m_markersTreeModel( nullptr ),
         m_unconnectedTreeModel( nullptr ),
         m_fpWarningsTreeModel( nullptr ),
-        m_severities( RPT_SEVERITY_ERROR | RPT_SEVERITY_WARNING )
+        m_severities( RPT_SEVERITY_ERROR | RPT_SEVERITY_WARNING ),
+        m_lastUpdateUi( std::chrono::steady_clock::now() )
 {
     SetName( DIALOG_DRC_WINDOW_NAME ); // Set a window name to be able to find it
 
@@ -208,8 +210,20 @@ bool DIALOG_DRC::updateUI()
 {
     double cur = alg::clamp( 0.0, (double) m_progress.load() / m_maxProgress, 1.0 );
 
-    m_gauge->SetValue( KiROUND( cur * 1000.0 ) );
-    wxSafeYield( this );
+    int newValue = KiROUND( cur * 1000.0 );
+    m_gauge->SetValue( newValue );
+
+    // There is significant overhead on at least Windows when updateUi is called constantly thousands of times
+    // in the drc process and safeyieldfor is called each time.
+    // Gate the yield to a limited rate which still allows the UI to function without slowing down the main thread
+    // which is also running DRC
+    std::chrono::steady_clock::time_point now = std::chrono::steady_clock::now();
+    if( std::chrono::duration_cast<std::chrono::milliseconds>( now - m_lastUpdateUi ).count()
+        > 100 )
+    {
+        Pgm().App().SafeYieldFor( this, wxEVT_CATEGORY_NATIVE_EVENTS );
+        m_lastUpdateUi = now;
+    }
 
     return !m_cancelled;
 }
@@ -485,6 +499,8 @@ void DIALOG_DRC::OnDRCItemSelected( wxDataViewEvent& aEvent )
 
         if( item->Type() == PCB_ZONE_T )
         {
+            m_frame->FocusOnItem( item, principalLayer );
+
             m_frame->GetBoard()->GetConnectivity()->RunOnUnconnectedEdges(
                     [&]( CN_EDGE& edge )
                     {
@@ -497,12 +513,25 @@ void DIALOG_DRC::OnDRCItemSelected( wxDataViewEvent& aEvent )
                             return true;
 
                         if( edge.GetSourceNode()->Parent() == a
-                                && edge.GetTargetNode()->Parent() == b )
+                            && edge.GetTargetNode()->Parent() == b )
                         {
-                            if( item == a )
-                                m_frame->FocusOnLocation( edge.GetSourcePos() );
+                            VECTOR2I focusPos;
+
+                            if( item == a && item == b )
+                            {
+                                focusPos = ( node->m_Type == RC_TREE_NODE::MAIN_ITEM )
+                                                   ? edge.GetSourcePos()
+                                                   : edge.GetTargetPos();
+                            }
                             else
-                                m_frame->FocusOnLocation( edge.GetTargetPos() );
+                            {
+                                focusPos = ( item == edge.GetSourceNode()->Parent() )
+                                                   ? edge.GetSourcePos()
+                                                   : edge.GetTargetPos();
+                            }
+
+                            m_frame->FocusOnLocation( focusPos );
+                            m_frame->RefreshCanvas();
 
                             return false;
                         }
