@@ -428,8 +428,8 @@ bool DIALOG_TEXT_PROPERTIES::TransferDataFromWindow()
     if( !DIALOG_TEXT_PROPERTIES_BASE::TransferDataFromWindow() )
         return false;
 
-    int minSize = pcbIUScale.MilsToIU( TEXT_MIN_SIZE_MILS );
-    int maxSize = pcbIUScale.MilsToIU( TEXT_MAX_SIZE_MILS );
+    int minSize = pcbIUScale.mmToIU( TEXT_MIN_SIZE_MM );
+    int maxSize = pcbIUScale.mmToIU( TEXT_MAX_SIZE_MM );
 
     if( !m_textWidth.Validate( minSize, maxSize ) || !m_textHeight.Validate( minSize, maxSize ) )
         return false;
