@@ -1,7 +1,7 @@
 /*
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
- * Copyright (C) 1992-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -118,9 +118,22 @@ void PlotInteractiveLayer( BOARD* aBoard, PLOTTER* aPlotter, const PCB_PLOT_PARA
                                                    _( "Keywords" ),
                                                    fp->GetKeywords() ) );
 #endif
-        aPlotter->HyperlinkMenu( fp->GetBoundingBox(), properties );
+        // Draw items are plotted with a position offset. So we need to move
+        // our boxes (which are not plotted) by the same offset.
+        VECTOR2I offset = -aPlotter->GetPlotOffsetUserUnits();
 
-        aPlotter->Bookmark( fp->GetBoundingBox(), fp->GetReference(), _( "Footprints" ) );
+        // Use a footprint bbox without texts to create the hyperlink area
+        BOX2I bbox = fp->GetBoundingBox( false, false );
+        bbox.Move( offset );
+        aPlotter->HyperlinkMenu( bbox, properties );
+
+        // Use a footprint bbox with visible texts only to create the bookmark area
+        // which is the area to zoom on ft selection
+        // However the bbox need to be inflated for a better look.
+        bbox = fp->GetBoundingBox( true, false );
+        bbox.Move( offset );
+        bbox.Inflate( bbox.GetWidth() /2, bbox.GetHeight() /2 );
+        aPlotter->Bookmark( bbox, fp->GetReference(), _( "Footprints" ) );
     }
 }
 
@@ -381,7 +394,9 @@ void PlotStandardLayer( BOARD* aBoard, PLOTTER* aPlotter, LSET aLayerMask,
             PAD_SHAPE padShape = pad->GetShape();
             VECTOR2I  padSize = pad->GetSize();
             VECTOR2I  padDelta = pad->GetDelta(); // has meaning only for trapezoidal pads
-            double    padCornerRadius = pad->GetRoundRectCornerRadius();
+            // CornerRadius and CornerRadiusRatio can be modified
+            // the radius is built from the ratio, so saving/restoring the ratio is enough
+            double    padCornerRadiusRatio = pad->GetRoundRectRadiusRatio();
 
             // Don't draw a 0 sized pad.
             // Note: a custom pad can have its pad anchor with size = 0
@@ -492,9 +507,10 @@ void PlotStandardLayer( BOARD* aBoard, PLOTTER* aPlotter, LSET aLayerMask,
                     // and use a dummy  CUSTOM pad to plot the final shape.
                     PAD dummy( *pad );
                     // Build the dummy pad outline with coordinates relative to the pad position
-                    // and orientation 0. The actual pos and rotation will be taken in account
-                    // later by the plot function
+                    // pad offset and orientation 0. The actual pos, offset and rotation will be
+                    // taken in account later by the plot function
                     dummy.SetPosition( VECTOR2I( 0, 0 ) );
+                    dummy.SetOffset( VECTOR2I( 0, 0 ) );
                     dummy.SetOrientation( ANGLE_0 );
                     SHAPE_POLY_SET outline;
                     dummy.TransformShapeToPolygon( outline, UNDEFINED_LAYER, 0, maxError,
@@ -513,7 +529,9 @@ void PlotStandardLayer( BOARD* aBoard, PLOTTER* aPlotter, LSET aLayerMask,
                     // anchor will be added to the pad shape when plotting the pad.
                     // So we set the anchor size to 0
                     dummy.SetSize( VECTOR2I( 0, 0 ) );
+                    // Restore pad position and offset
                     dummy.SetPosition( pad->GetPosition() );
+                    dummy.SetOffset( pad->GetOffset() );
                     dummy.SetOrientation( pad->GetOrientation() );
 
                     itemplotter.PlotPad( &dummy, color, padPlotMode );
@@ -554,7 +572,7 @@ void PlotStandardLayer( BOARD* aBoard, PLOTTER* aPlotter, LSET aLayerMask,
             pad->SetSize( padSize );
             pad->SetDelta( padDelta );
             pad->SetShape( padShape );
-            pad->SetRoundRectCornerRadius( padCornerRadius );
+            pad->SetRoundRectRadiusRatio( padCornerRadiusRatio );
         }
 
         aPlotter->EndBlock( nullptr );
