@@ -93,7 +93,9 @@ namespace std
     {
         std::size_t operator()( const CLEARANCE_CACHE_KEY& k ) const
         {
-            return hash<const void*>()( k.A ) ^ hash<const void*>()( k.B ) ^ hash<int>()( k.Flag );
+            size_t retval = 0xBADC0FFEE0DDF00D;
+            hash_combine( retval, hash<const void*>()( k.A ), hash<const void*>()( k.B ), hash<int>()( k.Flag ) );
+            return retval;
         }
     };
 }
@@ -1274,9 +1276,9 @@ bool PNS_KICAD_IFACE_BASE::syncZone( PNS::NODE* aWorld, ZONE* aZone, SHAPE_POLY_
         if( !layers[ layer ] )
             continue;
 
-        for( int outline = 0; outline < poly->OutlineCount(); outline++ )
+        for( int polyId = 0; polyId < poly->TriangulatedPolyCount(); polyId++ )
         {
-            const SHAPE_POLY_SET::TRIANGULATED_POLYGON* tri = poly->TriangulatedPolygon( outline );
+            const SHAPE_POLY_SET::TRIANGULATED_POLYGON* tri = poly->TriangulatedPolygon( polyId );
 
             for( size_t i = 0; i < tri->GetTriangleCount(); i++)
             {
@@ -1814,6 +1816,9 @@ void PNS_KICAD_IFACE::modifyBoardItem( PNS::ITEM* aItem )
         PNS::ARC*        arc = static_cast<PNS::ARC*>( aItem );
         PCB_ARC*         arc_board = static_cast<PCB_ARC*>( board_item );
         const SHAPE_ARC* arc_shape = static_cast<const SHAPE_ARC*>( arc->Shape() );
+
+        m_commit->Modify( arc_board );
+
         arc_board->SetStart( VECTOR2I( arc_shape->GetP0() ) );
         arc_board->SetEnd( VECTOR2I( arc_shape->GetP1() ) );
         arc_board->SetMid( VECTOR2I( arc_shape->GetArcMid() ) );
@@ -1826,6 +1831,9 @@ void PNS_KICAD_IFACE::modifyBoardItem( PNS::ITEM* aItem )
         PNS::SEGMENT* seg = static_cast<PNS::SEGMENT*>( aItem );
         PCB_TRACK*    track = static_cast<PCB_TRACK*>( board_item );
         const SEG&    s = seg->Seg();
+
+        m_commit->Modify( track );
+
         track->SetStart( VECTOR2I( s.A.x, s.A.y ) );
         track->SetEnd( VECTOR2I( s.B.x, s.B.y ) );
         track->SetWidth( seg->Width() );
@@ -1836,6 +1844,9 @@ void PNS_KICAD_IFACE::modifyBoardItem( PNS::ITEM* aItem )
     {
         PCB_VIA*  via_board = static_cast<PCB_VIA*>( board_item );
         PNS::VIA* via = static_cast<PNS::VIA*>( aItem );
+
+        m_commit->Modify( via_board );
+
         via_board->SetPosition( VECTOR2I( via->Pos().x, via->Pos().y ) );
         via_board->SetWidth( via->Diameter() );
         via_board->SetDrill( via->Drill() );
@@ -1852,20 +1863,22 @@ void PNS_KICAD_IFACE::modifyBoardItem( PNS::ITEM* aItem )
         PAD*     pad = static_cast<PAD*>( aItem->Parent() );
         VECTOR2I pos = static_cast<PNS::SOLID*>( aItem )->Pos();
 
+        // Don't add to commit; we'll add the parent footprints when processing the m_fpOffsets
+
         m_fpOffsets[pad].p_old = pad->GetPosition();
         m_fpOffsets[pad].p_new = pos;
         break;
     }
 
-    default: break;
+    default:
+        m_commit->Modify( aItem->Parent() );
+        break;
     }
 }
 
 
 void PNS_KICAD_IFACE::UpdateItem( PNS::ITEM* aItem )
 {
-    BOARD_ITEM* board_item = aItem->Parent();
-    m_commit->Modify( board_item );
     modifyBoardItem( aItem );
 }
 
@@ -1877,8 +1890,11 @@ void PNS_KICAD_IFACE_BASE::AddItem( PNS::ITEM* aItem )
 
 BOARD_CONNECTED_ITEM* PNS_KICAD_IFACE::createBoardItem( PNS::ITEM* aItem )
 {
-    BOARD_CONNECTED_ITEM* newBI = nullptr;
-    auto net = static_cast<NETINFO_ITEM*>( aItem->Net() );
+    BOARD_CONNECTED_ITEM* newBoardItem = nullptr;
+    NETINFO_ITEM* net = static_cast<NETINFO_ITEM*>( aItem->Net() );
+
+    if( !net )
+        net = NETINFO_LIST::OrphanedItem();
 
     switch( aItem->Kind() )
     {
@@ -1889,7 +1905,7 @@ BOARD_CONNECTED_ITEM* PNS_KICAD_IFACE::createBoardItem( PNS::ITEM* aItem )
         new_arc->SetWidth( arc->Width() );
         new_arc->SetLayer( ToLAYER_ID( arc->Layers().Start() ) );
         new_arc->SetNet( net );
-        newBI = new_arc;
+        newBoardItem = new_arc;
         break;
     }
 
@@ -1903,7 +1919,7 @@ BOARD_CONNECTED_ITEM* PNS_KICAD_IFACE::createBoardItem( PNS::ITEM* aItem )
         track->SetWidth( seg->Width() );
         track->SetLayer( ToLAYER_ID( seg->Layers().Start() ) );
         track->SetNet( net );
-        newBI = track;
+        newBoardItem = track;
         break;
     }
 
@@ -1919,7 +1935,7 @@ BOARD_CONNECTED_ITEM* PNS_KICAD_IFACE::createBoardItem( PNS::ITEM* aItem )
         via_board->SetIsFree( via->IsFree() );
         via_board->SetLayerPair( ToLAYER_ID( via->Layers().Start() ),
                                  ToLAYER_ID( via->Layers().End() ) );
-        newBI = via_board;
+        newBoardItem = via_board;
         break;
     }
 
@@ -1938,12 +1954,13 @@ BOARD_CONNECTED_ITEM* PNS_KICAD_IFACE::createBoardItem( PNS::ITEM* aItem )
 
     if( net->GetNetCode() <= 0 )
     {
-        NETINFO_ITEM* newNetInfo = newBI->GetNet();
+        NETINFO_ITEM* newNetInfo = newBoardItem->GetNet();
+
         newNetInfo->SetParent( m_board );
         newNetInfo->SetNetClass( m_board->GetDesignSettings().m_NetSettings->m_DefaultNetClass );
     }
 
-    return newBI;
+    return newBoardItem;
 }
 
 
