@@ -40,6 +40,7 @@
 #include <settings/settings_manager.h>
 #include <trigo.h>
 #include <i18n_utility.h>
+#include <mutex>
 
 
 ZONE::ZONE( BOARD_ITEM_CONTAINER* aParent ) :
@@ -344,15 +345,22 @@ const BOX2I ZONE::GetBoundingBox() const
     if( const BOARD* board = GetBoard() )
     {
         std::unordered_map<const ZONE*, BOX2I>& cache = board->m_ZoneBBoxCache;
-        auto                                    cacheIter = cache.find( this );
 
-        if( cacheIter != cache.end() )
-            return cacheIter->second;
+        {
+            std::shared_lock<std::shared_mutex> readLock( board->m_CachesMutex );
+
+            auto cacheIter = cache.find( this );
+
+            if( cacheIter != cache.end() )
+                return cacheIter->second;
+        }
 
         BOX2I bbox = m_Poly->BBox();
 
-        std::unique_lock<std::mutex> cacheLock( const_cast<BOARD*>( board )->m_CachesMutex );
-        cache[ this ] = bbox;
+        {
+            std::unique_lock<std::shared_mutex> writeLock( board->m_CachesMutex );
+            cache[ this ] = bbox;
+        }
 
         return bbox;
     }
@@ -363,16 +371,9 @@ const BOX2I ZONE::GetBoundingBox() const
 
 void ZONE::CacheBoundingBox()
 {
-    BOARD*                                  board = GetBoard();
-    std::unordered_map<const ZONE*, BOX2I>& cache = board->m_ZoneBBoxCache;
-
-    auto cacheIter = cache.find( this );
-
-    if( cacheIter == cache.end() )
-    {
-        std::unique_lock<std::mutex> cacheLock( board->m_CachesMutex );
-        cache[ this ] = m_Poly->BBox();
-    }
+    // GetBoundingBox() will cache it for us, and there's no sense duplicating the somewhat tricky
+    // locking code.
+    GetBoundingBox();
 }
 
 
