@@ -45,6 +45,7 @@ struct SLC_CASES
     SHAPE_LINE_CHAIN DuplicateArcs;
     SHAPE_LINE_CHAIN ArcsAndSegMixed;
     SHAPE_LINE_CHAIN ArcAndPoint;
+    SHAPE_LINE_CHAIN SegAndArcCoincident;
     SHAPE_LINE_CHAIN EmptyChain;
     SHAPE_LINE_CHAIN OnePoint;
     SHAPE_LINE_CHAIN TwoPoints;
@@ -55,6 +56,7 @@ struct SLC_CASES
     SHAPE_ARC Arc0b; ///< Second half of a circle
     SHAPE_ARC Arc1; ///< start coincident with Arc0a end
     SHAPE_ARC Arc2; ///< Independent arc
+    SHAPE_ARC Arc3; ///< Arc with angle >180
 
     SLC_CASES()
     {
@@ -78,6 +80,10 @@ struct SLC_CASES
                                VECTOR2I( 283650000, 228560000 ),
                                VECTOR2I( 283850000, 228360000 ), 0 );
 
+        Arc3 =      SHAPE_ARC( VECTOR2I( 0,         0 ),
+                               VECTOR2I( 24142136,  10000000 ),
+                               VECTOR2I( 0,         20000000 ), 0 );
+
         Circle1Arc.Append( ArcCircle );
         Circle1Arc.SetClosed( true );
 
@@ -110,12 +116,90 @@ struct SLC_CASES
 
         ThreePoints = TwoPoints;
         ThreePoints.Append( VECTOR2I( 263450000, 308360000 ) );
+
+        SegAndArcCoincident.Append( VECTOR2I( 0, 20000000 ) );
+        SegAndArcCoincident.Append( Arc3 );
     }
 };
 
 
 BOOST_FIXTURE_TEST_SUITE( TestShapeLineChain, SLC_CASES )
 
+
+BOOST_AUTO_TEST_CASE( ClipperConstructorCase1 )
+{
+    // Case of an arc followed by a segment
+    // The clipper path is not in order (on purpose), to simulate the typical return from clipper
+
+    ClipperLib::Path pathClipper1 = {
+        { { 125663951, 120099260, 24 }, { 125388111, 120170850, 25 }, { 125124975, 120280270, 26 },
+          { 124879705, 120425376, 27 }, { 124657110, 120603322, 28 }, { 124461556, 120810617, 29 },
+          { 124296876, 121043198, 30 }, { 124166301, 121296503, 31 }, { 124072391, 121565564, 32 },
+          { 124016988, 121845106, 33 }, { 124001177, 122129646, 34 }, { 124025270, 122413605, 35 },
+          { 124088794, 122691414, 36 }, { 124190502, 122957625, 37 }, { 124328401, 123207018, 38 },
+          { 124499787, 123434703, 39 }, { 124598846, 123537154, 40 }, { 127171000, 123786000, 4 },
+          { 127287862, 123704439, 5 },  { 127499716, 123513831, 6 },  { 127682866, 123295498, 7 },
+          { 127833720, 123053722, 8 },  { 127949321, 122793242, 9 },  { 128027402, 122519168, 10 },
+          { 128066430, 122236874, 11 }, { 128065642, 121951896, 12 }, { 128025053, 121669823, 13 },
+          { 127945457, 121396185, 14 }, { 127828417, 121136349, 15 }, { 127676227, 120895410, 16 },
+          { 127491873, 120678094, 17 }, { 127278968, 120488661, 18 }, { 127041689, 120330827, 19 },
+          { 126784688, 120207687, 20 }, { 126513005, 120121655, 21 }, { 126231968, 120074419, 22 },
+          { 125947087, 120066905, 23 } }
+    };
+    Clipper2Lib::Path64 pathClipper2 = {
+        { { 125663951, 120099260, 24 }, { 125388111, 120170850, 25 }, { 125124975, 120280270, 26 },
+          { 124879705, 120425376, 27 }, { 124657110, 120603322, 28 }, { 124461556, 120810617, 29 },
+          { 124296876, 121043198, 30 }, { 124166301, 121296503, 31 }, { 124072391, 121565564, 32 },
+          { 124016988, 121845106, 33 }, { 124001177, 122129646, 34 }, { 124025270, 122413605, 35 },
+          { 124088794, 122691414, 36 }, { 124190502, 122957625, 37 }, { 124328401, 123207018, 38 },
+          { 124499787, 123434703, 39 }, { 124598846, 123537154, 40 }, { 127171000, 123786000, 4 },
+          { 127287862, 123704439, 5 },  { 127499716, 123513831, 6 },  { 127682866, 123295498, 7 },
+          { 127833720, 123053722, 8 },  { 127949321, 122793242, 9 },  { 128027402, 122519168, 10 },
+          { 128066430, 122236874, 11 }, { 128065642, 121951896, 12 }, { 128025053, 121669823, 13 },
+          { 127945457, 121396185, 14 }, { 127828417, 121136349, 15 }, { 127676227, 120895410, 16 },
+          { 127491873, 120678094, 17 }, { 127278968, 120488661, 18 }, { 127041689, 120330827, 19 },
+          { 126784688, 120207687, 20 }, { 126513005, 120121655, 21 }, { 126231968, 120074419, 22 },
+          { 125947087, 120066905, 23 } }
+    };
+
+    std::vector<CLIPPER_Z_VALUE> z_values = {
+        { { -1, -1 }, 0 }, { { -1, -1 }, 0 }, { { -1, -1 }, 0 }, { { -1, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },  { { 0, -1 }, 0 },
+        { { 0, -1 }, 0 }
+    };
+
+    std::vector<SHAPE_ARC> arcs = {
+        SHAPE_ARC( { 127171000, 123786000 }, { 126231718, 120077003 }, { 124598846, 123537154 }, 0 )
+    };
+
+    SHAPE_LINE_CHAIN clipper1chain( pathClipper1, z_values, arcs );
+    SHAPE_LINE_CHAIN clipper2chain( pathClipper2, z_values, arcs );
+
+    BOOST_CHECK( GEOM_TEST::IsOutlineValid( clipper1chain ) );
+    BOOST_CHECK( GEOM_TEST::IsOutlineValid( clipper2chain ) );
+
+    BOOST_CHECK_EQUAL( clipper1chain.PointCount(), 37 );
+    BOOST_CHECK_EQUAL( clipper2chain.PointCount(), 37 );
+
+    BOOST_CHECK_EQUAL( clipper1chain.ArcCount(), 1 );
+    BOOST_CHECK_EQUAL( clipper2chain.ArcCount(), 1 );
+
+    BOOST_CHECK_EQUAL( clipper1chain.ShapeCount(), 2 );
+    BOOST_CHECK_EQUAL( clipper2chain.ShapeCount(), 2 );
+
+    BOOST_CHECK_EQUAL( clipper1chain.IsClosed(), true );
+    BOOST_CHECK_EQUAL( clipper2chain.IsClosed(), true );
+}
+
+
 BOOST_AUTO_TEST_CASE( ArcToPolyline )
 {
     SHAPE_LINE_CHAIN base_chain( { VECTOR2I( 0, 0 ), VECTOR2I( 0, 1000 ), VECTOR2I( 1000, 0 ) } );
@@ -246,6 +330,9 @@ static const std::vector<CLOSE_TOGGLE_SHAPE_CASE> close_toggle_shape_cases =
             { "ArcsCoincident",       SLC_CASES().ArcsCoincident,       false, 2, 14, 3, 14 },
             { "ArcsCoincidentClosed", SLC_CASES().ArcsCoincidentClosed, true,  3, 14, 2, 14 },
             { "ArcsIndependent",      SLC_CASES().ArcsIndependent,      false, 3, 18, 4, 18 },
+            // SegAndArcCoincident will remove the segment after SetClosed(true) and SetClosed(false)
+            // disable test for now
+            //{ "SegAndArcCoincident",  SLC_CASES().SegAndArcCoincident,  false, 2, 92, 2, 91 },
             { "DuplicateArcs",        SLC_CASES().DuplicateArcs,        false, 4, 20, 5, 20 },
             { "ArcAndPoint",          SLC_CASES().ArcAndPoint,          false, 2, 10, 3, 10 },
             { "ArcsAndSegMixed",      SLC_CASES().ArcsAndSegMixed,      false, 4, 19, 5, 19 },
@@ -431,6 +518,7 @@ BOOST_AUTO_TEST_CASE( ShapeCount )
     BOOST_CHECK_EQUAL( DuplicateArcs.ShapeCount(), 4 );
     BOOST_CHECK_EQUAL( ArcAndPoint.ShapeCount(), 2 );
     BOOST_CHECK_EQUAL( ArcsAndSegMixed.ShapeCount(), 4 );
+    BOOST_CHECK_EQUAL( SegAndArcCoincident.ShapeCount(), 2 );
     BOOST_CHECK_EQUAL( EmptyChain.ShapeCount(), 0 );
     BOOST_CHECK_EQUAL( OnePoint.ShapeCount(), 0 );
     BOOST_CHECK_EQUAL( TwoPoints.ShapeCount(), 1 );
@@ -471,6 +559,9 @@ BOOST_AUTO_TEST_CASE( NextShape )
     BOOST_CHECK_EQUAL( ArcsAndSegMixed.NextShape( 20 ), -1 ); //invalid indices should still work
     BOOST_CHECK_EQUAL( ArcsAndSegMixed.NextShape( -50 ), -1 ); //invalid indices should still work
 
+    BOOST_CHECK_EQUAL( SegAndArcCoincident.NextShape( 0 ), 1 ); // next shape Arc3
+    BOOST_CHECK_EQUAL( SegAndArcCoincident.NextShape( 1 ), -1 ); //no more shapes
+
     BOOST_CHECK_EQUAL( EmptyChain.NextShape( 0 ), -1 );
     BOOST_CHECK_EQUAL( EmptyChain.NextShape( 1 ), -1 ); //invalid indices should still work
     BOOST_CHECK_EQUAL( EmptyChain.NextShape( 2 ), -1 ); //invalid indices should still work
